Struct interoptopus_backend_cpython::Config [−][src]
pub struct Config {
pub init_api_function_name: String,
pub ffi_attribute: String,
pub raw_fn_namespace: String,
pub callback_namespace: String,
}Expand description
Configures Python code generation.
Fields
init_api_function_name: StringHow to name the function responsible for loading the DLL, e.g., init_api.
ffi_attribute: StringAttribute by which the cffi object is exposed, e.g., ffi.
raw_fn_namespace: StringNamespace to put functions into, e.g., api.
callback_namespace: StringNamespace for callback helpers, e.g., callbacks.